==> hplip_0.9.2.orig.tar.gz: hplip-0.9.2/io/hpiod/channel.h <==
/*****************************************************************************\

  channel.h - base class for MLC and Raw channels 
 
  (c) 2004 Copyright Hewlett-Packard Development Company, LP

  Permission is hereby granted, free of charge, to any person obtaining a copy 
  of this software and associated documentation files (the "Software"), to deal 
  in the Software without restriction, including without limitation the rights 
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
  of the Software, and to permit persons to whom the Software is furnished to do 
  so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

\*****************************************************************************/

#ifndef _CHANNEL_H
#define _CHANNEL_H

//Channel
//! Class that encapsulates common channel services. Channels
//! have a unique service name and only one service name can be open at a time.
/*!
******************************************************************************/
class Channel
{
   unsigned char sockid;    /* static socket id */

protected:
   Device *pDev;
   int ClientCnt;           /* number of clients using this device */
   int Index;             /* Device::pChannel[index] of this object */

public:
   Channel(Device *pDev);
   virtual ~Channel();

   inline int GetIndex() { return Index; }
   inline void SetIndex(int i) { Index=i; }
   inline int GetClientCnt() { return ClientCnt; }
   inline void SetClientCnt(int i) { ClientCnt=i; }
   inline unsigned char GetSocketID() { return sockid; }
   inline void SetSocketID(unsigned char s) { sockid=s; }
   virtual int Open(char *sendBuf, int *result);
   virtual int Close(char *sendBuf, int *result);
   virtual int WriteData(unsigned char *data, int length, char *sendBuf, int *result);
   virtual int ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result);   

}; //Channel

//RawChannel
//! Class that encapsulates raw channel services.
/*!
******************************************************************************/
class RawChannel : public Channel
{
public:
   RawChannel(Device *pDev) : Channel(pDev) {}
}; //RawChannel

//JetdirectChannel
//! Class that encapsulates jetdirect channel services.
/*!
******************************************************************************/
class JetDirectChannel : public Channel
{
   int Socket;
   int ReadReply();

public:
   JetDirectChannel(Device *pDev);

   int Open(char *sendBuf, int *result);
   int Close(char *sendBuf, int *result);
   int WriteData(unsigned char *data, int length, char *sendBuf, int *result);
   int ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result);   
}; //JetdirectChannel

/*
 * See mlc.h for MlcChannel class definition.
 */

#endif // _CHANNEL_H

==> hplip_0.9.5.orig.tar.gz: hplip-0.9.5/io/hpiod/channel.h <==
/*****************************************************************************\

  channel.h - base class for MLC and Raw channels 
 
  (c) 2004 Copyright Hewlett-Packard Development Company, LP

  Permission is hereby granted, free of charge, to any person obtaining a copy 
  of this software and associated documentation files (the "Software"), to deal 
  in the Software without restriction, including without limitation the rights 
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
  of the Software, and to permit persons to whom the Software is furnished to do 
  so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

\*****************************************************************************/

#ifndef _CHANNEL_H
#define _CHANNEL_H

//Channel
//! Class that encapsulates common channel services. Channels
//! have a unique service name and only one service name can be open at a time.
/*!
******************************************************************************/
class Channel
{
   unsigned char sockid;    /* static socket id */

protected:
   Device *pDev;
   int ClientCnt;           /* number of clients using this device */
   int Index;             /* Device::pChannel[index] of this object */

public:
   Channel(Device *pDev);
   virtual ~Channel();

   inline int GetIndex() { return Index; }
   inline void SetIndex(int i) { Index=i; }
   inline int GetClientCnt() { return ClientCnt; }
   inline void SetClientCnt(int i) { ClientCnt=i; }
   inline unsigned char GetSocketID() { return sockid; }
   inline void SetSocketID(unsigned char s) { sockid=s; }
   virtual int Open(char *sendBuf, int *result);
   virtual int Close(char *sendBuf, int *result);
   virtual int WriteData(unsigned char *data, int length, char *sendBuf, int *result);
   virtual int ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result);   

}; //Channel

//RawChannel
//! Class that encapsulates raw channel services.
/*!
******************************************************************************/
class RawChannel : public Channel
{
public:
   RawChannel(Device *pDev) : Channel(pDev) {}
}; //RawChannel

//JetdirectChannel
//! Class that encapsulates jetdirect channel services.
/*!
******************************************************************************/
class JetDirectChannel : public Channel
{
   int Socket;
   int ReadReply();

public:
   JetDirectChannel(Device *pDev);

   int Open(char *sendBuf, int *result);
   int Close(char *sendBuf, int *result);
   int WriteData(unsigned char *data, int length, char *sendBuf, int *result);
   int ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result);   
}; //JetdirectChannel

//#define MAX_COMMAND_PACKET 64
#define MAX_COMMAND_PACKET BUFFER_SIZE  
#define MAX_SENDER_DATA BUFFER_SIZE
#define MAX_RECEIVER_DATA BUFFER_SIZE

//MlcChannel
//! Class that encapsulates common channel services requiring MLC.
/*!
******************************************************************************/
class MlcChannel : public Channel
{
//   unsigned short h2psize;  /* host to peripheral packet size in bytes */
//   unsigned short p2hsize;  /* peripheral to host packet size in bytes */
   unsigned short credit;  /* host to peripheral credit */
   unsigned short p2hcredit;  /* peripheral to host credit */   
//   int CurrentProtocol;
   unsigned char rbuf[MAX_RECEIVER_DATA];  /* read packet buffer */
   int rindex;
   int rcnt;

public:
   MlcChannel(Device *pDev);

   inline unsigned short GetH2PSize() { return pDev->CA[GetSocketID()].h2psize; }
   inline void SetH2PSize(unsigned short i) { pDev->CA[GetSocketID()].h2psize=i; }
   inline unsigned short GetP2HSize() { return pDev->CA[GetSocketID()].p2hsize; }
   inline void SetP2HSize(unsigned short i) { pDev->CA[GetSocketID()].p2hsize=i; }
   inline unsigned short GetP2HCredit() { return p2hcredit; }
   inline void SetP2HCredit(unsigned short i) { p2hcredit=i; }
   inline unsigned short GetH2PCredit() { return credit; }
   inline void SetH2PCredit(unsigned short i) { credit=i; }

   int MlcSocket2Channel(unsigned char sockid);
   int MlcForwardReply(int fd, unsigned char *buf, int size);
   int MlcExecReverseCmd(int fd, unsigned char *buf);
   int MlcReverseCmd(int fd);
   int MlcReverseReply(int fd, unsigned char *buf, int bufsize);
   int MlcCredit(int fd, unsigned short credit);
   int MlcCreditRequest(int fd, unsigned short credit);
   int MlcForwardData(int fd, int sockid, unsigned char *buf, int size);
   int MlcReverseData(int fd, int sockid, unsigned char *buf, int bufsize, int timeout);
   int MlcInit(int fd);
   int MlcExit(int fd);
   int MlcConfigSocket(int fd);
   int MlcOpenChannel(int fd);
   int MlcCloseChannel(int fd);
   virtual int Open(char *sendBuf, int *result);
   virtual int Close(char *sendBuf, int *result);
   int WriteData(unsigned char *data, int length, char *sendBuf, int *result);
   int ReadData(int length, int timeout, char *sendBuf, int sendBufLength, int *result);   
   int CutBuf(char *sendBuf, int length);

}; //MlcDevice

class ParMlcChannel : public MlcChannel
{

public:
   ParMlcChannel(Device *pDev);

   int Open(char *sendBuf, int *result);
   int Close(char *sendBuf, int *result);
}; 

#endif // _CHANNEL_H
